## AOP切面埋点方案，引入es7 decorator，彻底与业务解耦


> 引入   npm install aop-monitor --save

#### 使用方式
> ps: 初始化代码只需编写一次，以后每个组件都引用这个aopMonitor就可以了
```js
1. 初始化aop-monitor      export const aopMonitor = initAopMonitor(send)
2. 编写埋点代码watchList   export const watchList = {}
3. 业务代码引入装饰器       @aopMonitor(watchList)
                            
```

#### example
> aopMonitor.js ---- 初始化aop-monitor

```js
import initAopMonitor from 'aop-monitor';

// log 代表你系统内部发送埋点的方法，将其注入initMonitor中，即可得到一个可供任何地方使用的aop埋点工具
const log = params => console.log(JSON.stringify(params));
const aopMonitor = initAopMonitor(log);

export default aopMonitor;
```

> monitor.js ---- 编写埋点代码watchList
```js
const watchList = {
    // 方法名必须与业务里的方法保持一致
    fn1() {
      console.log('after fn1');
      return {
        fnName: 'fn1'
      }
    },
    fn2() {
      console.log('after fn2');
      return {
        fnName: 'fn2'
      }
    }
};

export default watchList;
```

> MyClass.js ---- 业务代码引入装饰器 
```js
import aopMonitor from './aopMonitor'
import watchList from './monitor';

// 通过decorator的方式来进行监控，彻底与业务代码解耦
@aopMonitor(watchList)
class MyClass {
    constructor() {
        this.fn1();
        this.fn2();
    }
    fn1() {
        console.log('fn1')
    }
    fn2() {
        console.log('fn2')
    }
}

new MyClass()

```

> 打印结果

```js

"fn1"

"after fn1"

"{\"fnName\":\"fn1\"}"

"fn2"

"after fn2"

"{\"fnName\":\"fn2\"}"

```
